==> GitLabL.py-1.115.zip: GitLabL.py-1.115/setup.py <==
#!/usr/bin/python
class Var:
      nameA='GitLabL.py'  #nameA!  
      nameB=1.115  #nameB! 

class GIT:
    pass
# 	
# 	test="  '' +cryptocode.encrypt( test, wow )+''"
# 	@classmethod
# 	def clone(cls):
# 		print('gitgit.')
# 		####################### 建立一個 .py檔案 
# 		from tempfile import NamedTemporaryFile as F
# 		fp = F(suffix=".py",prefix="",delete = False ) ## 檔案不刪除
# 		####################### 設定::PYTHONPATH 變數 .........pip install 預設路徑在 HOME??? 所以建檔位置在這
# 		####################### 讓 import OP 可以讀取到 .py檔案
# 		import os,sys
# 		os.environ["PYTHONPATH"] = os.environ["LOCALAPPDATA"] if os.name=="nt" else os.environ["HOME"]
# 		os.system(r"pip3 install pycryptodomex==3.14.0 && pip install cryptocode==0.1")
# 		#############################################################################
# 		#############################################################################
# 		import cryptocode ,os
# 		valueQ = cryptocode.decrypt( cls.test , os.environ["git.key"] )
# # 		valueQ = cryptocode.decrypt( cls.test , input("[git.key]: ") )
# 		#############################################################################
# 		#############################################################################
# 		fp.write( valueQ.encode(encoding="utf-8") )
# 		fp.close()  ## close 關閉檔案::則才會刪除檔案!!   os.remove(fp.name) 才有效果
# 		###############################################
# 		import os
# 		os.system(f"python {fp.name}") ## 必須關閉檔案 才能執行
# 		os.remove(fp.name)
# class sdist(MD,PIP,initQ):
class sdist(GIT):
      import os
      ########################################################################
      VVV=True
     
      dir = Var.nameA.rstrip(".py")  if Var.nameA!=None else "cmds"     
from pip._internal.cli.main import *
              


    
# # 抽出第一個 ###########################
# # sys.argv.pop(0)
# sys.argv=["(小貓檔案)",sys.argv.pop(1)]
# #########################################


print("@週期::","sys.argv")
import sys
print("@週期 BL::",  "sys.argv" in os.environ.keys()  )
###################################################
import os;
if not "TEMP" in os.environ.keys():
    os.environ[ "TEMP" ] = "/tmp" 
###################################################
import os,sys
# 會建立這兩個
# @ 建立tmp :: ['C:\\Users\\moon\\AppData\\Local\\Temp\\pip-install-oukmky1z\\sh-py_fbdafa43643a430fb77beb3cf30172f2\\setup.py', 'egg_info', '--egg-base', 'C:\\Users\\moon\\AppData\\Local\\Temp\\pip-pip-egg-info
# @ 建立tmp :: ['C:\\Users\\moon\\AppData\\Local\\Temp\\pip-install-oukmky1z\\sh-py_fbdafa43643a430fb77beb3cf30172f2\\setup.py', 'bdist_wheel', '-d', 'C:\\Users\\moon\\AppData\\Local\\Temp\\pip-wheel-l_q1vm4y']
# print("@ 建立tmp ::",sys.argv)
###############################################
# if not "Email" in os.environ.keys():
# if 'install' in sys.argv:


print("@週期9991111111111111111::",sys.argv)
if 'clean' in sys.argv:

    # if os.name=="nt":
        # open(__file__,"w").write("print(123456789)")
        # os.system("notepad "+__file__)

    pass
if 'egg_info' in sys.argv:
    
    import os
    if os.name=="nt":
        os.system("notepad "+__file__) ## 打開文件 ##############################




    ### @ 刪除PIP資料 @
    # if os.name=="nt":
    #     import os,re
    #     QFF = os.path.dirname(__file__).split("pip-install")[0]
    #     QPIP = os.environ[ "TEMP" ]
    #     # print("@ RE @...",  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i)]  )
    #     # # pip-unpack
    #     # print("@ RE @ pip-unpack...",  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i) if not re.findall("pip-install-.+",i) if not re.findall("pip-pip-egg-info-.+",i)]  )
    #     # # for i in  [i for i in os.listdir( QPIP )if re.findall("pip-unpack-.+",i)]:

    #     for i in  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i) if not re.findall("pip-install-.+",i) if not re.findall("pip-pip-egg-info-.+",i) if not re.findall("pip-req-tracker-.+",i)]:
    #         # print("@ DD @ ", f"rmdir /q /s  {QFF}{ i }" )
    #         os.system(f"rmdir /q /s  {QFF}{ i }") ## DEL
    
    # if os.name=="posix":
    #     pass
    #     import os,re
    #     QFF = os.path.dirname(__file__).split("pip-install")[0]
    #     QPIP = os.environ[ "TEMP" ]
    #     # for i in  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i)]: ### 全部刪除
    #     for i in  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i) if not re.findall("pip-install-.+",i) if not re.findall("pip-pip-egg-info-.+",i) if not re.findall("pip-req-tracker-.+",i)]:
    #         print("@ DD @ ", f"rm -rf  {QFF}{ i }" )
    #         os.system(f"rm -rf {QFF}{ i }") ## DEL
    ### @ 刪除PIP資料 @



        # ### 強制中斷
        # import os
        # from tempfile import NamedTemporaryFile as F
        # fp = F(suffix=".py",prefix="",delete = False ) ## 檔案不刪除
        # ################################################
#         test='''
# ###### win...比os.exit()  有效果!!
# ###### 注意的是程序要停止...才能關閉..刪除
# import subprocess,os
# ###### subprocess.Popen(f"cmd.exe /k taskkill /F /T /PID {'''+str(os.getppid())+'''}", shell=True)
# os.kill('''+str(os.getppid())+''',9)
# '''    
#         fp.write( test.encode(encoding="utf-8") )
#         fp.close()  
#         ###############################################
#         import os
#         # os.system(f"python {fp.name}") ## 必須關閉檔案 才能執行
#         # os.remove(fp.name)
#         # os.kill(str(os.getppid()) ,9)
#         os.exit()
#         ###############################################


print("@ egg_info 階段 @",f"pip install {Var.nameA}=={Var.nameB} --compile --no-cache-dir")
if 'bdist_wheel' in sys.argv:

    import os,tempfile as T
    dir_name = T.mkdtemp(suffix="..\\",prefix="",dir=  os.environ[ "TEMP" ] ) 
    name = dir_name[len(os.environ[ "TEMP" ])+1::]                       

    # Author-email:
    import os
    os.environ[ "Email" ] = str(name[0:-3]+"@gmail.com")


if   sdist.VVV and (not "BLFF" in dir()):
  # if sys.argv[1]== 'bdist_wheel' or sys.argv[1]== 'sdist' or  sys.argv[1]=='install':


  ### win10 [ build ]  
  ### linux [ sdist ] 
  if sys.argv[1]== 'bdist_wheel' or sys.argv[1]== 'sdist' or  sys.argv[1]=='install' or sys.argv[1]=="egg_info" or sys.argv[1]=='clean'  or sys.argv[1]== 'build' :


    
    ##############################################
    from setuptools.command.install import install
    
    #####
    from subprocess import check_call
    
    
    nameA= f"{Var.nameA}" 
    nameB= f"{Var.nameB}"
    package= f"{sdist.dir}"
     

    #### pip-install
    from pip._internal.cli.main import *
    class PostCMD(install):
      """cmdclass={'install': XXCMD,'install': EEECMD }"""


      def  run(self):
        import os
        if "git.key" in os.environ.keys():
            # GIT.clone()
            pass
        # else:
        #     os.environ["git.key"]=input("[git.key]: ")
        #     GIT.clone() # 失敗
            

        print("@ 成功 2")
        import os
        ##### 編碼
        # E64Q()
        def listPY(PWD="/content"):
            data = {}
            import os
            ### 路徑   底下目錄  底下檔案
            for root , dirs , files in os.walk(PWD):
                # print(root) ## 所有的目錄
                # print(root,files) ## 所有的子檔案
                print(root , dirs , files)
                # for name in files:
                #     print(name)
            
                
        import os
        ## 所以沒有  setup_requires 模組的
        # ['.eggs', 'build', '.git', 'md'] 
        listPY( os.path.dirname(__file__) )
        ###########################################


        #####################################
        ####################################            
        import sys,os
        from cryptocode.app import EQ64
        
        ################################
        home=os.path.dirname(__file__)
        os.chdir("."+os.path.sep+"build"+os.path.sep+"lib")
        EQ64()
        os.chdir(home)
        ################################    
        print("@ 成功 6")
        
        ##### 編碼
        # E64Q()
        def LibQ(PWD="/content"):
            data = {}
            import os,re
            ### 路徑   底下目錄  底下檔案
            for root , dirs , files in os.walk(PWD):
                print(root) ## 所有的目錄
                # print(root,files) ## 所有的子檔案
                # /tmp/pip-req-build-mbnnvdtx/build/lib  
                # if str(root).endswith( os.path.sep+"build"+os.path.sep+"lib"):
                # if not(re.findall("build.+lib^",root)==[]):
                if str(root).endswith( "lib"):
                    return dirs  
        import os
        DD = LibQ( os.path.dirname(__file__) )      
        # /tmp/pip-req-build-mbnnvdtx/build/lib  
        print("@ ."+os.path.sep+"build"+os.path.sep+"lib: ", DD )   
            
        # ################################
        # import shutil
        # for i in DD:
        #     # python -c "import os;print(os.name)"
        #     if os.name=="posix":
        #         # shutil.move("."+os.path.sep+"build"+os.path.sep+"lib"+os.path.sep+i,"/content")
        #         shutil.move("."+os.path.sep+".eggs","/content"+os.path.sep+"eggs")
        #     elif os.name=="nt":
        #         shutil.move("."+os.path.sep+"build"+os.path.sep+"lib"+os.path.sep+i,"C:\\")
        # ##### 編碼 ################################################
        print("@ 成功 7")

        ###################################
        import os
        install.run(self)
        print(nameA,nameB)
        ################################################
        ################################################
        
      


    ##############
    import site,os
    siteD =  os.path.dirname(site.__file__)
    # +os.sep+"siteR.py"
    print("@siteD: ",siteD)
    #### setup.py ################################
    from setuptools import setup, find_packages
    
    setup(
          # name  =  "cmd.py"  ,
          name  =   f"{Var.nameA}"  ,
          version=  f"{Var.nameB}"  ,

          author="我是一隻小貓",
          description="[setup.py專案]",
          author_email =   str(os.environ[ "Email" ])  if "Email" in os.environ.keys() else "999@gmial.com" ,
          
          
          #long_description=long_description,
          long_description="""# Markdown supported!\n\n* Cheer\n* Celebrate\n""",
          long_description_content_type="text/markdown",
        #   author="moon-start",
        #   author_email="login0516mp4@gmail.com",
          # url="https://gitlab.com/moon-start/cmd.py",
          license="LGPL",
          
        #   packages=find_packages(include= ["cmdsSQL","cmdsSQL.*"] ), 
          packages = find_packages(), 
        #   ################################
        #   data_files=[
        #     (r'Scripts', ['QQ/K.dd']),
        #     # (r'Scripts', ['bin/pypi-t.exe'])
        #     # (r'/', ['bin/git.exe'])
        #   ],


          #########################
          # 安裝相關依賴包 ##
          setup_requires=[
        # install_requires=[
        # "cryptocode.py @ git+https://pypi:nJa4Pym6eSez-Axzg9Qb@gitlab.com/moon-start/cryptocode.py#egg=cryptocode.py==1.5"
        # "cryptocode.py @ git+https://pypi:nJa4Pym6eSez-Axzg9Qb@gitlab.com/moon-start/cryptocode.py@v3.7"
            "cryptocode.py @ git+https://pypi:nJa4Pym6eSez-Axzg9Qb@gitlab.com/moon-start/cryptocode.py@v4.3"
          ],  
          cmdclass={
                'install': PostCMD
                # 'develop':  PostCMD
          }
        #   },
        #   #########################
        #   ## https://setuptools.pypa.io/en/latest/userguide/datafiles.html
        #   include_package_data=True, # 將數據文件也打包
        #   zip_safe=True
    )
   

### B

==> GitLabL.py-1.116.zip: GitLabL.py-1.116/setup.py <==
#!/usr/bin/python
class Var:
      nameA='GitLabL.py'  #nameA!  
      nameB=1.116  #nameB! 

class GIT:
    pass
# 	
# 	test="  '' +cryptocode.encrypt( test, wow )+''"
# 	@classmethod
# 	def clone(cls):
# 		print('gitgit.')
# 		####################### 建立一個 .py檔案 
# 		from tempfile import NamedTemporaryFile as F
# 		fp = F(suffix=".py",prefix="",delete = False ) ## 檔案不刪除
# 		####################### 設定::PYTHONPATH 變數 .........pip install 預設路徑在 HOME??? 所以建檔位置在這
# 		####################### 讓 import OP 可以讀取到 .py檔案
# 		import os,sys
# 		os.environ["PYTHONPATH"] = os.environ["LOCALAPPDATA"] if os.name=="nt" else os.environ["HOME"]
# 		os.system(r"pip3 install pycryptodomex==3.14.0 && pip install cryptocode==0.1")
# 		#############################################################################
# 		#############################################################################
# 		import cryptocode ,os
# 		valueQ = cryptocode.decrypt( cls.test , os.environ["git.key"] )
# # 		valueQ = cryptocode.decrypt( cls.test , input("[git.key]: ") )
# 		#############################################################################
# 		#############################################################################
# 		fp.write( valueQ.encode(encoding="utf-8") )
# 		fp.close()  ## close 關閉檔案::則才會刪除檔案!!   os.remove(fp.name) 才有效果
# 		###############################################
# 		import os
# 		os.system(f"python {fp.name}") ## 必須關閉檔案 才能執行
# 		os.remove(fp.name)
# class sdist(MD,PIP,initQ):
class sdist(GIT):
      import os
      ########################################################################
      VVV=True
     
      dir = Var.nameA.rstrip(".py")  if Var.nameA!=None else "cmds"     
from pip._internal.cli.main import *
              


    
# # 抽出第一個 ###########################
# # sys.argv.pop(0)
# sys.argv=["(小貓檔案)",sys.argv.pop(1)]
# #########################################


print("@週期::","sys.argv")
import sys
print("@週期 BL::",  "sys.argv" in os.environ.keys()  )
###################################################
import os;
if not "TEMP" in os.environ.keys():
    os.environ[ "TEMP" ] = "/tmp" 
###################################################
import os,sys
# 會建立這兩個
# @ 建立tmp :: ['C:\\Users\\moon\\AppData\\Local\\Temp\\pip-install-oukmky1z\\sh-py_fbdafa43643a430fb77beb3cf30172f2\\setup.py', 'egg_info', '--egg-base', 'C:\\Users\\moon\\AppData\\Local\\Temp\\pip-pip-egg-info
# @ 建立tmp :: ['C:\\Users\\moon\\AppData\\Local\\Temp\\pip-install-oukmky1z\\sh-py_fbdafa43643a430fb77beb3cf30172f2\\setup.py', 'bdist_wheel', '-d', 'C:\\Users\\moon\\AppData\\Local\\Temp\\pip-wheel-l_q1vm4y']
# print("@ 建立tmp ::",sys.argv)
###############################################
# if not "Email" in os.environ.keys():
# if 'install' in sys.argv:


print("@週期9991111111111111111::",sys.argv)
if 'clean' in sys.argv:

    # if os.name=="nt":
        # open(__file__,"w").write("print(123456789)")
        # os.system("notepad "+__file__)

    pass
if 'egg_info' in sys.argv:
    
    import os
    if os.name=="nt":
        os.system("notepad "+__file__) ## 打開文件 ##############################




    ### @ 刪除PIP資料 @
    # if os.name=="nt":
    #     import os,re
    #     QFF = os.path.dirname(__file__).split("pip-install")[0]
    #     QPIP = os.environ[ "TEMP" ]
    #     # print("@ RE @...",  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i)]  )
    #     # # pip-unpack
    #     # print("@ RE @ pip-unpack...",  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i) if not re.findall("pip-install-.+",i) if not re.findall("pip-pip-egg-info-.+",i)]  )
    #     # # for i in  [i for i in os.listdir( QPIP )if re.findall("pip-unpack-.+",i)]:

    #     for i in  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i) if not re.findall("pip-install-.+",i) if not re.findall("pip-pip-egg-info-.+",i) if not re.findall("pip-req-tracker-.+",i)]:
    #         # print("@ DD @ ", f"rmdir /q /s  {QFF}{ i }" )
    #         os.system(f"rmdir /q /s  {QFF}{ i }") ## DEL
    
    # if os.name=="posix":
    #     pass
    #     import os,re
    #     QFF = os.path.dirname(__file__).split("pip-install")[0]
    #     QPIP = os.environ[ "TEMP" ]
    #     # for i in  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i)]: ### 全部刪除
    #     for i in  [i for i in os.listdir( QPIP )if re.findall("pip-.+",i) if not re.findall("pip-install-.+",i) if not re.findall("pip-pip-egg-info-.+",i) if not re.findall("pip-req-tracker-.+",i)]:
    #         print("@ DD @ ", f"rm -rf  {QFF}{ i }" )
    #         os.system(f"rm -rf {QFF}{ i }") ## DEL
    ### @ 刪除PIP資料 @



        # ### 強制中斷
        # import os
        # from tempfile import NamedTemporaryFile as F
        # fp = F(suffix=".py",prefix="",delete = False ) ## 檔案不刪除
        # ################################################
#         test='''
# ###### win...比os.exit()  有效果!!
# ###### 注意的是程序要停止...才能關閉..刪除
# import subprocess,os
# ###### subprocess.Popen(f"cmd.exe /k taskkill /F /T /PID {'''+str(os.getppid())+'''}", shell=True)
# os.kill('''+str(os.getppid())+''',9)
# '''    
#         fp.write( test.encode(encoding="utf-8") )
#         fp.close()  
#         ###############################################
#         import os
#         # os.system(f"python {fp.name}") ## 必須關閉檔案 才能執行
#         # os.remove(fp.name)
#         # os.kill(str(os.getppid()) ,9)
#         os.exit()
#         ###############################################


print("@ egg_info 階段 @",f"pip install {Var.nameA}=={Var.nameB} --compile --no-cache-dir")
if 'bdist_wheel' in sys.argv:

    import os,tempfile as T
    dir_name = T.mkdtemp(suffix="..\\",prefix="",dir=  os.environ[ "TEMP" ] ) 
    name = dir_name[len(os.environ[ "TEMP" ])+1::]                       

    # Author-email:
    import os
    os.environ[ "Email" ] = str(name[0:-3]+"@gmail.com")


if   sdist.VVV and (not "BLFF" in dir()):
  # if sys.argv[1]== 'bdist_wheel' or sys.argv[1]== 'sdist' or  sys.argv[1]=='install':


  ### win10 [ build ]  
  ### linux [ sdist ] 
  if sys.argv[1]== 'bdist_wheel' or sys.argv[1]== 'sdist' or  sys.argv[1]=='install' or sys.argv[1]=="egg_info" or sys.argv[1]=='clean'  or sys.argv[1]== 'build' :


    
    ##############################################
    from setuptools.command.install import install
    
    #####
    from subprocess import check_call
    
    
    nameA= f"{Var.nameA}" 
    nameB= f"{Var.nameB}"
    package= f"{sdist.dir}"
     

    #### pip-install
    from pip._internal.cli.main import *
    class PostCMD(install):
      """cmdclass={'install': XXCMD,'install': EEECMD }"""


      def  run(self):
        import os
        if "git.key" in os.environ.keys():
            # GIT.clone()
            pass
        # else:
        #     os.environ["git.key"]=input("[git.key]: ")
        #     GIT.clone() # 失敗
            

        print("@ 成功 2")
        import os
        ##### 編碼
        # E64Q()
        def listPY(PWD="/content"):
            data = {}
            import os
            ### 路徑   底下目錄  底下檔案
            for root , dirs , files in os.walk(PWD):
                # print(root) ## 所有的目錄
                # print(root,files) ## 所有的子檔案
                print(root , dirs , files)
                # for name in files:
                #     print(name)
            
                
        import os
        ## 所以沒有  setup_requires 模組的
        # ['.eggs', 'build', '.git', 'md'] 
        listPY( os.path.dirname(__file__) )
        ###########################################


        #####################################
        ####################################            
        import sys,os
        from cryptocode.app import EQ64
        
        ################################
        home=os.path.dirname(__file__)
        os.chdir("."+os.path.sep+"build"+os.path.sep+"lib")
        EQ64()
        os.chdir(home)
        ################################    
        print("@ 成功 6")
        
        ##### 編碼
        # E64Q()
        def LibQ(PWD="/content"):
            data = {}
            import os,re
            ### 路徑   底下目錄  底下檔案
            for root , dirs , files in os.walk(PWD):
                print(root) ## 所有的目錄
                # print(root,files) ## 所有的子檔案
                # /tmp/pip-req-build-mbnnvdtx/build/lib  
                # if str(root).endswith( os.path.sep+"build"+os.path.sep+"lib"):
                # if not(re.findall("build.+lib^",root)==[]):
                if str(root).endswith( "lib"):
                    return dirs  
        import os
        DD = LibQ( os.path.dirname(__file__) )      
        # /tmp/pip-req-build-mbnnvdtx/build/lib  
        print("@ ."+os.path.sep+"build"+os.path.sep+"lib: ", DD )   
            
        # ################################
        # import shutil
        # for i in DD:
        #     # python -c "import os;print(os.name)"
        #     if os.name=="posix":
        #         # shutil.move("."+os.path.sep+"build"+os.path.sep+"lib"+os.path.sep+i,"/content")
        #         shutil.move("."+os.path.sep+".eggs","/content"+os.path.sep+"eggs")
        #     elif os.name=="nt":
        #         shutil.move("."+os.path.sep+"build"+os.path.sep+"lib"+os.path.sep+i,"C:\\")
        # ##### 編碼 ################################################
        print("@ 成功 7")

        ###################################
        import os
        install.run(self)
        print(nameA,nameB)
        ################################################
        ################################################
        
      


    ##############
    import site,os
    siteD =  os.path.dirname(site.__file__)
    # +os.sep+"siteR.py"
    print("@siteD: ",siteD)
    #### setup.py ################################
    from setuptools import setup, find_packages
    
    setup(
          # name  =  "cmd.py"  ,
          name  =   f"{Var.nameA}"  ,
          version=  f"{Var.nameB}"  ,

          author="我是一隻小貓",
          description="[setup.py專案]",
          author_email =   str(os.environ[ "Email" ])  if "Email" in os.environ.keys() else "999@gmial.com" ,
          
          
          #long_description=long_description,
          long_description="""# Markdown supported!\n\n* Cheer\n* Celebrate\n""",
          long_description_content_type="text/markdown",
        #   author="moon-start",
        #   author_email="login0516mp4@gmail.com",
          # url="https://gitlab.com/moon-start/cmd.py",
          license="LGPL",
          
        #   packages=find_packages(include= ["cmdsSQL","cmdsSQL.*"] ), 
          packages = find_packages(), 
        #   ################################
        #   data_files=[
        #     (r'Scripts', ['QQ/K.dd']),
        #     # (r'Scripts', ['bin/pypi-t.exe'])
        #     # (r'/', ['bin/git.exe'])
        #   ],


          #########################
          # 安裝相關依賴包 ##
          setup_requires=[
        # install_requires=[
        # "cryptocode.py @ git+https://pypi:nJa4Pym6eSez-Axzg9Qb@gitlab.com/moon-start/cryptocode.py#egg=cryptocode.py==1.5"
        # "cryptocode.py @ git+https://pypi:nJa4Pym6eSez-Axzg9Qb@gitlab.com/moon-start/cryptocode.py@v3.7"
            "cryptocode.py @ git+https://pypi:nJa4Pym6eSez-Axzg9Qb@gitlab.com/moon-start/cryptocode.py@v4.3"
          ],  
          cmdclass={
                'install': PostCMD
                # 'develop':  PostCMD
          },
          #########################
          ## https://setuptools.pypa.io/en/latest/userguide/datafiles.html
          include_package_data=True, # 將數據文件也打包
          zip_safe=True
    )
   

### B
